Learn R Programming

krippendorffsalpha (version 2.0)

ratio.dist: Apply a ratio distance function to two scores.

Description

Apply a ratio distance function to two scores.

Usage

ratio.dist(x, y)

Value

\((x-y)^2/(x+y)^2\), or 0 if x or y is NA.

Arguments

x

a score.

y

a score.

Details

This function applies a ratio distance function to two scores. This may be an appropriate distance function for the ratio level of measurement. NA's are handled gracefully.

See Also

interval.dist, nominal.dist